EventGatekeeperUserOverride

Struct EventGatekeeperUserOverride 

pub struct EventGatekeeperUserOverride<'a> { /* private fields */ }
Available on macOS and crate feature macos_15_0_0 only.
Notification for a gatekeeper_user_override event.

This event type does not support caching (notify-only).

Hashes are calculated in usermode by Gatekeeper. There is no guarantee that any other program including the kernel will observe the same file at the reported path. Furthermore, there is no guarantee that the CDHash is valid or that it matches the containing binary.

Implementations

Source

impl<'a> EventGatekeeperUserOverride<'a>

pub fn file(&self) -> Option<GatekeeperFile<'a>>

Describes the target file that is being overridden by the user.

If Endpoint security can’t lookup the file at event submission it will emit a path instead of a File.

pub fn sha256(&self) -> &[u8; 32]

SHA256 of the file.

Provided if the filesize is less than 100MB.

pub fn signing_info(&self) -> Option<SignedFileInfo<'_>>

Signing Information, available if the file has been signed.