pub struct EventSignal<'a> { /* private fields */ }Available on macOS only.
Send a signal to a process event.
Signals may be sent on behalf of another process or directly. Notably launchd often sends signals on behalf of another process for service start/ stop operations. If this is the case an instigator will be provided. The relationship between each process is illustrated below:
Delegated Signal:
Instigator Process -> IPC to Sender Process (launchd) -> Target ProcessDirect Signal:
Sender Process -> Target ProcessClients may wish to block delegated signals from launchd for non-authorized instigators, while still allowing direct signals initiated by launchd for shutdown/reboot/restart.
Implementations
Sourceimpl<'a> EventSignal<'a>
impl<'a> EventSignal<'a>
Sourcepub fn instigator(&self) -> Option<Process<'a>>
Available on crate feature macos_15_4_0 only.
pub fn instigator(&self) -> Option<Process<'a>>
macos_15_4_0 only.Process information for the instigator.
Only available for delegated signals.
Note: Only available only if message version >= 9.