pub struct EventTccModify<'a> { /* private fields */ }Available on macOS and crate feature
macos_15_4_0 only.Expand description
TCC Modification Event.
Occurs when a TCC permission is granted or revoked.
Note: This event type does not support caching.
Implementations
Sourceimpl<'a> EventTccModify<'a>
impl<'a> EventTccModify<'a>
Sourcepub fn identity(&self) -> &'a OsStr
pub fn identity(&self) -> &'a OsStr
The identity of the application that is the subject of the permission.
Sourcepub fn identity_type(&self) -> es_tcc_identity_type_t
pub fn identity_type(&self) -> es_tcc_identity_type_t
The identity type of the application string (Bundle ID, path, etc).
Sourcepub fn update_type(&self) -> es_tcc_event_type_t
pub fn update_type(&self) -> es_tcc_event_type_t
The type of TCC modification event (Grant/Revoke etc)
Sourcepub fn instigator_token(&self) -> AuditToken
pub fn instigator_token(&self) -> AuditToken
Audit token of the instigator of the modification.
Sourcepub fn instigator(&self) -> Option<Process<'a>>
pub fn instigator(&self) -> Option<Process<'a>>
(Optional) The process information for the instigator.
Sourcepub fn responsible_token(&self) -> Option<AuditToken>
pub fn responsible_token(&self) -> Option<AuditToken>
(Optional) Audit token of the responsible process for the modification.
Sourcepub fn responsible(&self) -> Option<Process<'a>>
pub fn responsible(&self) -> Option<Process<'a>>
(Optional) The process information for the responsible process.
Sourcepub fn right(&self) -> es_tcc_authorization_right_t
pub fn right(&self) -> es_tcc_authorization_right_t
The resulting TCC permission of the operation/modification.
Sourcepub fn reason(&self) -> es_tcc_authorization_reason_t
pub fn reason(&self) -> es_tcc_authorization_reason_t
The reason the TCC permissions were updated.