pub struct SignedFileInfo<'a> { /* private fields */ }Available on macOS and crate feature
macos_15_0_0 only.Expand description
Information from a signed file.
If the file is a multiarchitecture binary, only the signing information for the native host architecture is reported. I.e. the CDHash from the AArch64 slice if the host is AArch64.
Implementations